@@ -1,5 +1,6 @@
 require 'spec_helper'
 describe 'apt::source', :type => :define do
+  let(:facts) { { :lsbdistid => 'Debian' } }
   let :title do
     'my_source'
   end
@@ -59,7 +60,7 @@ describe 'apt::source', :type => :define do
       end
 
       let :facts do
-        {:lsbdistcodename => 'karmic'}
+        {:lsbdistcodename => 'karmic', :lsbdistid => 'Ubuntu'}
       end
 
       let :params do
@@ -73,7 +74,7 @@ describe 'apt::source', :type => :define do
       let :content do
         content = "# #{title}"
         if param_hash[:architecture]
-          arch = "[arch=#{param_hash[:architecture]}]"
+          arch = "[arch=#{param_hash[:architecture]}] "
         end
         content << "\ndeb #{arch}#{param_hash[:location]} #{param_hash[:release]} #{param_hash[:repos]}\n"
 
@@ -160,7 +161,7 @@ describe 'apt::source', :type => :define do
     let(:default_params) { Hash.new }
     let(:facts) { Hash.new }
     it { expect { should raise_error(Puppet::Error) } }
-    let(:facts) { { :lsbdistcodename => 'lucid' } }
+    let(:facts) { { :lsbdistcodename => 'lucid', :lsbdistid => 'Ubuntu' } }
     it { should contain_apt__source(title) }
   end
 end
